# create our namespaces
resource "kubernetes_namespace" "managed" {
  for_each = toset(var.managed_namespaces)

  metadata {
    name = each.value
    labels = {
      "app.kubernetes.io/managed-by" = "Terraform"
    }
  }
}

# create managed secrets
resource "kubernetes_secret" "managed" {
  for_each = local.secrets_map

  metadata {
    name      = each.key
    namespace = each.value["namespace"]
    labels = {
      "app.kubernetes.io/managed-by" = "Terraform"
    }
  }

  type       = each.value["secret_type"]
  data       = each.value["data"]
  depends_on = [kubernetes_namespace.managed]
}

# create managed config maps
resource "kubernetes_config_map" "managed" {
  for_each = local.configs_map

  metadata {
    name      = each.key
    namespace = each.value["namespace"]
    labels = {
      "app.kubernetes.io/managed-by" = "Terraform"
    }
  }

  data        = each.value["data"]
  binary_data = lookup(each.value, "binary_data", null)
  depends_on  = [kubernetes_namespace.managed]
}
